==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Wylij");
define("_FYOURNAME","Twoje imi:");
define("_FYOUREMAIL","Twj email:");
define("_FFRIENDNAME","Imi Twego znajomego:");
define("_FFRIENDEMAIL","Email Twego znajomego:");
define("_HELLO","Hello");
define("_YOURFRIEND","Twj znajomy");
define("_RECOMMEND","Zarekomenduj t stron znajomym");
define("_INTSITE","Interesujca strona:");
define("_OURSITE","Uwaam, e ta strona jest");
define("_INTSENT","interesujca i warta poinformowania Ciebie o jej istnieniu.");
define("_FSITENAME","Nazwa strony:");
define("_FSITEURL","Adres strony:");
define("_FREFERENCE","Referencje ne temat naszej strony zostay wysane do");
define("_THANKSREC","Dzikujemy za zarekomendowanie nas!");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Wylij");
define("_FYOURNAME","Twoje imi:");
define("_FYOUREMAIL","Twj email:");
define("_FFRIENDNAME","Imi Twego znajomego:");
define("_FFRIENDEMAIL","Email Twego znajomego:");
define("_HELLO","Hello");
define("_YOURFRIEND","Twj znajomy");
define("_RECOMMEND","Zarekomenduj t stron znajomym");
define("_INTSITE","Interesujca strona:");
define("_OURSITE","Uwaam, e ta strona jest");
define("_INTSENT","interesujca i warta poinformowania Ciebie o jej istnieniu.");
define("_FSITENAME","Nazwa strony:");
define("_FSITEURL","Adres strony:");
define("_FREFERENCE","Referencje ne temat naszej strony zostay wysane do");
define("_THANKSREC","Dzikujemy za zarekomendowanie nas!");

?>
